Class: AutoItX3::ComboBox

Inherits:
ListBox show all
Defined in:
lib/AutoItX3/control.rb

Overview

A combo box is a control on which you click and then select a single item from the droped list box.

Instance Method Summary collapse

Methods inherited from ListBox

#<<, #add_item, #current_selection, #current_selection=, #delete, #find, #select_string

Methods inherited from Control

#click, #disable, #enable, #enabled?, #focus, from_control, functions, functions=, #handle, #hide, #initialize, #move, #rect, #send_command_to_control, #send_keys, #show, #text, #text=, #visible?

Constructor Details

This class inherits a constructor from AutoItX3::Control

Instance Method Details

#dropObject

Drops down a combo box. ===Return value Unknown. ===Raises [Au3Error] Control or window not found. ===Example box.drop



455
456
457
# File 'lib/AutoItX3/control.rb', line 455

def drop
  send_command_to_control("ShowDropDown")
end

#undropObject Also known as: close

call-seq: undrop close

Undrops or closes a combo box. ===Return value Unknown. ===Raises [Au3Error] Control or window not found.



468
469
470
# File 'lib/AutoItX3/control.rb', line 468

def undrop
  send_command_to_control("HideDropDown")
end